==> bibledit-0.9.tar.gz: bibledit-0.9/src/windowscompanion.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_WINDOWSCOMPANION_H
#define INCLUDED_WINDOWSCOMPANION_H


#include "libraries.h"
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <stdio.h>


class WindowsCompanion
{
public:
  WindowsCompanion (bool dummy);
  virtual ~WindowsCompanion ();
  virtual void Clear ();
  virtual void Connect (const string & host, unsigned int portnumber);
  virtual void Tick ();
  virtual void Disconnect (bool message = true);
  virtual void Sendln (const string & command);
  virtual string Readln ();
private:
  struct sockaddr_in address;
  struct in_addr inaddr;
  struct hostent *host;
  int sock;
  int stage;
  string hostname;
  unsigned int port;
  virtual void RunStages ();
  bool run_stages;
  bool stages_running;
  bool thread_running;
  bool connected;
  virtual void log (const string & message);
  virtual void reconnect ();
  static void local_thread_connect(gpointer data);
  virtual void thread_connect ();
};


#endif

==> bibledit-1.4.tar.gz: bibledit-1.4/src/windowscompanion.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_WINDOWSCOMPANION_H
#define INCLUDED_WINDOWSCOMPANION_H


#include "libraries.h"
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <stdio.h>


class WindowsCompanion
{
public:
  WindowsCompanion (bool dummy);
  virtual ~WindowsCompanion ();
  virtual void Clear ();
  virtual void Connect (const ustring & host, unsigned int portnumber);
  virtual void Tick ();
  virtual void Disconnect (bool message = true);
  virtual void sendreference (const ustring& book, const ustring& chapter, const ustring& verse);
private:
  struct sockaddr_in address;
  struct in_addr inaddr;
  struct hostent *host;
  int sock;
  int stage;
  ustring hostname;
  unsigned int port;
  virtual void RunStages ();
  bool run_stages;
  bool stages_running;
  bool thread_running;
  bool connected;
  virtual void log (const ustring & message);
  virtual void reconnect ();
  static void local_thread_connect(gpointer data);
  virtual void thread_connect ();
  virtual void Sendln (const ustring & command);
  virtual ustring Readln ();
};


#endif
